# My BirchRest Project

Full documentation of BirchRest is found here:
https://alexandengstrom.github.io/birchrest

CLI Commands:

```bash
birch lint # lints the project with pylint (if enabled)

birch typecheck # type checks the project with mypy (if enabled)

birch test # run all unittests using python unittest module
```